# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`pkgng`](#pkgng): This configures the PkgNG Package manager on FreeBSD systems, and adds support for managing packages with Puppet.  This will eventually be in

### Defined types

* [`pkgng::repo`](#pkgng--repo): This configures a single PkgNG repository. Instead of defining the repo with the repo URL, we split it up in hostname, mirror_type, protocol 

### Data types

* [`Pkgng::Mirror_type`](#Pkgng--Mirror_type): The type of a pkg mirror
* [`Pkgng::Protocol`](#Pkgng--Protocol): The protocol for a pkg mirror

## Classes

### <a name="pkgng"></a>`pkgng`

This configures the PkgNG Package manager on FreeBSD systems, and adds
support for managing packages with Puppet.  This will eventually be in
mainline FreeBSD, but for now, we are leaving the installation up to the
administrator, since there is no going back.

If you have purge_repos_d as true - then you'll have no repositories
defined unless you define one. You want to do this as you'll want this
module to control repos anyway.

To install PkgNG, one can simply run the following:
make -C /usr/ports/ports-mgmg/pkg install clean

#### Examples

##### 

```puppet
include pkgng
```

#### Parameters

The following parameters are available in the `pkgng` class:

* [`pkg_dbdir`](#-pkgng--pkg_dbdir)
* [`pkg_cachedir`](#-pkgng--pkg_cachedir)
* [`portsdir`](#-pkgng--portsdir)
* [`options`](#-pkgng--options)
* [`purge_repos_d`](#-pkgng--purge_repos_d)
* [`repos`](#-pkgng--repos)

##### <a name="-pkgng--pkg_dbdir"></a>`pkg_dbdir`

Data type: `Stdlib::Absolutepath`

Full path to database directory for pkg(8)

Default value: `'/var/db/pkg'`

##### <a name="-pkgng--pkg_cachedir"></a>`pkg_cachedir`

Data type: `Stdlib::Absolutepath`

Full path to cache directory for pkg(8)

Default value: `'/var/cache/pkg'`

##### <a name="-pkgng--portsdir"></a>`portsdir`

Data type: `Stdlib::Absolutepath`

Full path to ports directory

Default value: `'/usr/ports'`

##### <a name="-pkgng--options"></a>`options`

Data type: `Array[String]`

Extra options to write to pkg.conf(5)

Default value: `[]`

##### <a name="-pkgng--purge_repos_d"></a>`purge_repos_d`

Data type: `Boolean`

Whether unmanaged repositories should be removed

Default value: `true`

##### <a name="-pkgng--repos"></a>`repos`

Data type: `Hash`

Repositories to manage using create_resources()

Default value: `{}`

## Defined types

### <a name="pkgng--repo"></a>`pkgng::repo`

This configures a single PkgNG repository. Instead of defining the repo
with the repo URL, we split it up in hostname, mirror_type, protocol and
repopath. This way, this resource can be integrated with possible firewalls
better.

#### Examples

##### to use the class

```puppet
pkg::repo { 'pkg.example.com': }
```

#### Parameters

The following parameters are available in the `pkgng::repo` defined type:

* [`packagehost`](#-pkgng--repo--packagehost)
* [`protocol`](#-pkgng--repo--protocol)
* [`mirror_type`](#-pkgng--repo--mirror_type)
* [`repopath`](#-pkgng--repo--repopath)
* [`enabled`](#-pkgng--repo--enabled)
* [`priority`](#-pkgng--repo--priority)
* [`pubkey`](#-pkgng--repo--pubkey)
* [`fingerprints`](#-pkgng--repo--fingerprints)

##### <a name="-pkgng--repo--packagehost"></a>`packagehost`

Data type: `String[1]`

Hostname of the repository

Default value: `$name`

##### <a name="-pkgng--repo--protocol"></a>`protocol`

Data type: `Pkgng::Protocol`

Transport used to reach the repository

Default value: `'http'`

##### <a name="-pkgng--repo--mirror_type"></a>`mirror_type`

Data type: `Pkgng::Mirror_type`

Mirror type of the repository

Default value: `'srv'`

##### <a name="-pkgng--repo--repopath"></a>`repopath`

Data type: `Stdlib::Absolutepath`

Path of the repository on packagehost

Default value: `'/${ABI}/latest'`

##### <a name="-pkgng--repo--enabled"></a>`enabled`

Data type: `Boolean`

Whether this repository is currently enabled

Default value: `true`

##### <a name="-pkgng--repo--priority"></a>`priority`

Data type: `Integer[0,100]`

Priority of the repository

Default value: `0`

##### <a name="-pkgng--repo--pubkey"></a>`pubkey`

Data type: `Optional[Stdlib::Absolutepath]`

Path to the file containing  the public key for this repository

Default value: `undef`

##### <a name="-pkgng--repo--fingerprints"></a>`fingerprints`

Data type: `Optional[Stdlib::Absolutepath]`

Path to the file containing known signatures for the repository

Default value: `undef`

## Data types

### <a name="Pkgng--Mirror_type"></a>`Pkgng::Mirror_type`

The type of a pkg mirror

Alias of `Enum['http', 'none', 'srv']`

### <a name="Pkgng--Protocol"></a>`Pkgng::Protocol`

The protocol for a pkg mirror

Alias of `Enum['file', 'ftp', 'http', 'https', 'ssh']`

